summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJose Alberto Reguero <jareguero@telefonica.net>2012-08-29 11:35:03 +0300
committerJose Alberto Reguero <jareguero@telefonica.net>2012-08-29 11:35:03 +0300
commit1a8845bd908d506fb304eead688c2366427c5826 (patch)
treec896e6e522837e6aab72f47225d7a7a62f62bab8
parent45df9747488edfa16cf8add07351b14782c553fc (diff)
downloadxine-lib-1a8845bd908d506fb304eead688c2366427c5826.tar.gz
xine-lib-1a8845bd908d506fb304eead688c2366427c5826.tar.bz2
ff_audio_decoder: enable parser for EAC3
-rw-r--r--src/combined/ffmpeg/ff_audio_decoder.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/combined/ffmpeg/ff_audio_decoder.c b/src/combined/ffmpeg/ff_audio_decoder.c
index 740595b9e..553d79c85 100644
--- a/src/combined/ffmpeg/ff_audio_decoder.c
+++ b/src/combined/ffmpeg/ff_audio_decoder.c
@@ -162,13 +162,14 @@ static void ff_audio_init_codec(ff_audio_decoder_t *this, unsigned int codec_typ
this->context->codec_type = this->codec->type;
this->context->codec_tag = _x_stream_info_get(this->stream, XINE_STREAM_INFO_AUDIO_FOURCC);
/* Use parser for AAC LATM and MPEG.
* Fixes:
* - DVB streams where multiple AAC LATM frames are packed to single PES
* - DVB streams where MPEG audio frames do not follow PES packet boundaries
*/
#if AVPARSE > 1
if (codec_type == BUF_AUDIO_AAC_LATM ||
+ codec_type == BUF_AUDIO_EAC3 ||
codec_type == BUF_AUDIO_MPEG) {
xprintf (this->stream->xine, XINE_VERBOSITY_DEBUG,
@@ -162,13 +162,14 @@ static void ff_audio_init_codec(ff_audio_decoder_t *this, unsigned int codec_typ
this->context->codec_type = this->codec->type;
this->context->codec_tag = _x_stream_info_get(this->stream, XINE_STREAM_INFO_AUDIO_FOURCC);
- /* Use parser for AAC LATM and MPEG.
+ /* Use parser for EAC3, AAC LATM and MPEG.
* Fixes:
* - DVB streams where multiple AAC LATM frames are packed to single PES